@@ -26,9 +26,7 @@ from perun.connector.perun_openapi.model.assigned_member import AssignedMember
 from perun.connector.perun_openapi.model.assigned_resource import AssignedResource
 from perun.connector.perun_openapi.model.attribute import Attribute
 from perun.connector.perun_openapi.model.attribute_action import AttributeAction
-from perun.connector.perun_openapi.model.attribute_all_of import AttributeAllOf
 from perun.connector.perun_openapi.model.attribute_definition import AttributeDefinition
-from perun.connector.perun_openapi.model.attribute_definition_all_of import AttributeDefinitionAllOf
 from perun.connector.perun_openapi.model.attribute_policy import AttributePolicy
 from perun.connector.perun_openapi.model.attribute_policy_collection import AttributePolicyCollection
 from perun.connector.perun_openapi.model.attribute_rights import AttributeRights
@@ -36,32 +34,20 @@ from perun.connector.perun_openapi.model.audit_event import AuditEvent
 from perun.connector.perun_openapi.model.audit_message import AuditMessage
 from perun.connector.perun_openapi.model.audit_messages_page_query import AuditMessagesPageQuery
 from perun.connector.perun_openapi.model.auditable import Auditable
-from perun.connector.perun_openapi.model.auditable_all_of import AuditableAllOf
 from perun.connector.perun_openapi.model.author import Author
-from perun.connector.perun_openapi.model.author_all_of import AuthorAllOf
 from perun.connector.perun_openapi.model.authorship import Authorship
-from perun.connector.perun_openapi.model.authorship_all_of import AuthorshipAllOf
 from perun.connector.perun_openapi.model.authz_roles import AuthzRoles
 from perun.connector.perun_openapi.model.ban import Ban
-from perun.connector.perun_openapi.model.ban_all_of import BanAllOf
 from perun.connector.perun_openapi.model.ban_on_facility import BanOnFacility
-from perun.connector.perun_openapi.model.ban_on_facility_all_of import BanOnFacilityAllOf
 from perun.connector.perun_openapi.model.ban_on_resource import BanOnResource
-from perun.connector.perun_openapi.model.ban_on_resource_all_of import BanOnResourceAllOf
 from perun.connector.perun_openapi.model.ban_on_vo import BanOnVo
-from perun.connector.perun_openapi.model.ban_on_vo_all_of import BanOnVoAllOf
 from perun.connector.perun_openapi.model.brand import Brand
 from perun.connector.perun_openapi.model.candidate import Candidate
-from perun.connector.perun_openapi.model.candidate_all_of import CandidateAllOf
 from perun.connector.perun_openapi.model.category import Category
-from perun.connector.perun_openapi.model.category_all_of import CategoryAllOf
 from perun.connector.perun_openapi.model.consent import Consent
-from perun.connector.perun_openapi.model.consent_all_of import ConsentAllOf
 from perun.connector.perun_openapi.model.consent_hub import ConsentHub
-from perun.connector.perun_openapi.model.consent_hub_all_of import ConsentHubAllOf
 from perun.connector.perun_openapi.model.consent_status import ConsentStatus
 from perun.connector.perun_openapi.model.destination import Destination
-from perun.connector.perun_openapi.model.destination_all_of import DestinationAllOf
 from perun.connector.perun_openapi.model.destination_propagation_type import DestinationPropagationType
 from perun.connector.perun_openapi.model.destination_type import DestinationType
 from perun.connector.perun_openapi.model.enriched_facility import EnrichedFacility
@@ -71,10 +57,8 @@ from perun.connector.perun_openapi.model.enriched_resource import EnrichedResour
 from perun.connector.perun_openapi.model.enriched_vo import EnrichedVo
 from perun.connector.perun_openapi.model.entityless_attributes_by_keys import EntitylessAttributesByKeys
 from perun.connector.perun_openapi.model.ext_source import ExtSource
-from perun.connector.perun_openapi.model.ext_source_all_of import ExtSourceAllOf
 from perun.connector.perun_openapi.model.ext_source_object import ExtSourceObject
 from perun.connector.perun_openapi.model.facility import Facility
-from perun.connector.perun_openapi.model.facility_all_of import FacilityAllOf
 from perun.connector.perun_openapi.model.facility_propagation_state import FacilityPropagationState
 from perun.connector.perun_openapi.model.facility_state import FacilityState
 from perun.connector.perun_openapi.model.gen_data_node import GenDataNode
@@ -82,7 +66,6 @@ from perun.connector.perun_openapi.model.gen_member_data_node import GenMemberDa
 from perun.connector.perun_openapi.model.graph_dto import GraphDTO
 from perun.connector.perun_openapi.model.graph_file_format import GraphFileFormat
 from perun.connector.perun_openapi.model.group import Group
-from perun.connector.perun_openapi.model.group_all_of import GroupAllOf
 from perun.connector.perun_openapi.model.group_member_data import GroupMemberData
 from perun.connector.perun_openapi.model.group_member_relation import GroupMemberRelation
 from perun.connector.perun_openapi.model.group_resource_status import GroupResourceStatus
@@ -90,7 +73,6 @@ from perun.connector.perun_openapi.model.groups_order_column import GroupsOrderC
 from perun.connector.perun_openapi.model.groups_page_query import GroupsPageQuery
 from perun.connector.perun_openapi.model.hashed_gen_data import HashedGenData
 from perun.connector.perun_openapi.model.host import Host
-from perun.connector.perun_openapi.model.host_all_of import HostAllOf
 from perun.connector.perun_openapi.model.identity import Identity
 from perun.connector.perun_openapi.model.input_add_application_mail_for_group import InputAddApplicationMailForGroup
 from perun.connector.perun_openapi.model.input_add_application_mail_for_vo import InputAddApplicationMailForVo
@@ -208,7 +190,6 @@ from perun.connector.perun_openapi.model.item_texts import ItemTexts
 from perun.connector.perun_openapi.model.mail_text import MailText
 from perun.connector.perun_openapi.model.mail_type import MailType
 from perun.connector.perun_openapi.model.member import Member
-from perun.connector.perun_openapi.model.member_all_of import MemberAllOf
 from perun.connector.perun_openapi.model.member_candidate import MemberCandidate
 from perun.connector.perun_openapi.model.member_group_status import MemberGroupStatus
 from perun.connector.perun_openapi.model.member_with_sponsors import MemberWithSponsors
@@ -217,7 +198,6 @@ from perun.connector.perun_openapi.model.members_page_query import MembersPageQu
 from perun.connector.perun_openapi.model.namespace_rules import NamespaceRules
 from perun.connector.perun_openapi.model.new_apps import NewApps
 from perun.connector.perun_openapi.model.owner import Owner
-from perun.connector.perun_openapi.model.owner_all_of import OwnerAllOf
 from perun.connector.perun_openapi.model.owner_type import OwnerType
 from perun.connector.perun_openapi.model.paginated_audit_messages import PaginatedAuditMessages
 from perun.connector.perun_openapi.model.paginated_rich_applications import PaginatedRichApplications
@@ -230,43 +210,28 @@ from perun.connector.perun_openapi.model.perun_exception import PerunException
 from perun.connector.perun_openapi.model.perun_policy import PerunPolicy
 from perun.connector.perun_openapi.model.perun_principal import PerunPrincipal
 from perun.connector.perun_openapi.model.publication import Publication
-from perun.connector.perun_openapi.model.publication_all_of import PublicationAllOf
 from perun.connector.perun_openapi.model.publication_for_gui import PublicationForGUI
-from perun.connector.perun_openapi.model.publication_for_gui_all_of import PublicationForGUIAllOf
 from perun.connector.perun_openapi.model.publication_system import PublicationSystem
-from perun.connector.perun_openapi.model.publication_system_all_of import PublicationSystemAllOf
 from perun.connector.perun_openapi.model.rt_message import RTMessage
 from perun.connector.perun_openapi.model.resource import Resource
-from perun.connector.perun_openapi.model.resource_all_of import ResourceAllOf
 from perun.connector.perun_openapi.model.resource_state import ResourceState
 from perun.connector.perun_openapi.model.resource_tag import ResourceTag
-from perun.connector.perun_openapi.model.resource_tag_all_of import ResourceTagAllOf
 from perun.connector.perun_openapi.model.rich_application import RichApplication
-from perun.connector.perun_openapi.model.rich_application_all_of import RichApplicationAllOf
 from perun.connector.perun_openapi.model.rich_destination import RichDestination
-from perun.connector.perun_openapi.model.rich_destination_all_of import RichDestinationAllOf
 from perun.connector.perun_openapi.model.rich_facility import RichFacility
-from perun.connector.perun_openapi.model.rich_facility_all_of import RichFacilityAllOf
 from perun.connector.perun_openapi.model.rich_group import RichGroup
-from perun.connector.perun_openapi.model.rich_group_all_of import RichGroupAllOf
 from perun.connector.perun_openapi.model.rich_member import RichMember
-from perun.connector.perun_openapi.model.rich_member_all_of import RichMemberAllOf
 from perun.connector.perun_openapi.model.rich_resource import RichResource
-from perun.connector.perun_openapi.model.rich_resource_all_of import RichResourceAllOf
 from perun.connector.perun_openapi.model.rich_user import RichUser
-from perun.connector.perun_openapi.model.rich_user_all_of import RichUserAllOf
 from perun.connector.perun_openapi.model.rich_user_ext_source import RichUserExtSource
 from perun.connector.perun_openapi.model.role_management_rules import RoleManagementRules
 from perun.connector.perun_openapi.model.role_object import RoleObject
 from perun.connector.perun_openapi.model.security_team import SecurityTeam
 from perun.connector.perun_openapi.model.service import Service
-from perun.connector.perun_openapi.model.service_all_of import ServiceAllOf
 from perun.connector.perun_openapi.model.service_attributes import ServiceAttributes
 from perun.connector.perun_openapi.model.service_for_gui import ServiceForGUI
-from perun.connector.perun_openapi.model.service_for_gui_all_of import ServiceForGUIAllOf
 from perun.connector.perun_openapi.model.service_state import ServiceState
 from perun.connector.perun_openapi.model.services_package import ServicesPackage
-from perun.connector.perun_openapi.model.services_package_all_of import ServicesPackageAllOf
 from perun.connector.perun_openapi.model.set_role_with_group_complementary_object import SetRoleWithGroupComplementaryObject
 from perun.connector.perun_openapi.model.set_role_with_user_complementary_object import SetRoleWithUserComplementaryObject
 from perun.connector.perun_openapi.model.simple_attribute import SimpleAttribute
@@ -278,24 +243,18 @@ from perun.connector.perun_openapi.model.task_and_destination_id_object import T
 from perun.connector.perun_openapi.model.task_and_destination_name_object import TaskAndDestinationNameObject
 from perun.connector.perun_openapi.model.task_id_object import TaskIdObject
 from perun.connector.perun_openapi.model.task_result import TaskResult
-from perun.connector.perun_openapi.model.task_result_all_of import TaskResultAllOf
 from perun.connector.perun_openapi.model.task_result_id_object import TaskResultIdObject
 from perun.connector.perun_openapi.model.task_result_status import TaskResultStatus
 from perun.connector.perun_openapi.model.task_status import TaskStatus
 from perun.connector.perun_openapi.model.thanks import Thanks
-from perun.connector.perun_openapi.model.thanks_all_of import ThanksAllOf
 from perun.connector.perun_openapi.model.thanks_for_gui import ThanksForGUI
-from perun.connector.perun_openapi.model.thanks_for_gui_all_of import ThanksForGUIAllOf
 from perun.connector.perun_openapi.model.type import Type
 from perun.connector.perun_openapi.model.unset_role_with_group_complementary_object import UnsetRoleWithGroupComplementaryObject
 from perun.connector.perun_openapi.model.unset_role_with_user_complementary_object import UnsetRoleWithUserComplementaryObject
 from perun.connector.perun_openapi.model.user import User
-from perun.connector.perun_openapi.model.user_all_of import UserAllOf
 from perun.connector.perun_openapi.model.user_ext_source import UserExtSource
-from perun.connector.perun_openapi.model.user_ext_source_all_of import UserExtSourceAllOf
 from perun.connector.perun_openapi.model.users_order_column import UsersOrderColumn
 from perun.connector.perun_openapi.model.users_page_query import UsersPageQuery
 from perun.connector.perun_openapi.model.vo import Vo
 from perun.connector.perun_openapi.model.vo_admin_roles import VoAdminRoles
-from perun.connector.perun_openapi.model.vo_all_of import VoAllOf
 from perun.connector.perun_openapi.model.vo_member_statuses import VoMemberStatuses
